summaryrefslogtreecommitdiff
path: root/vw-bap.h
diff options
context:
space:
mode:
authornorly <ny-git@enpas.org>2019-02-24 04:35:59 +0100
committernorly <ny-git@enpas.org>2019-02-24 04:35:59 +0100
commit8c73fd11fe9cac11ba2fdd657b84f845632af3d0 (patch)
tree103046069c53a18dce2a2b839ca1e132cc09172e /vw-bap.h
parent04795b52688dde6f4ad0284a633f5ffb4aec80e0 (diff)
Rename BAP 'function' to 'port'
This is more generic, thus allowing for interpreting it as 'registers', and easier to understand when coming from UDP/IP.
Diffstat (limited to 'vw-bap.h')
-rw-r--r--vw-bap.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/vw-bap.h b/vw-bap.h
index 87a2fc3..4e6d124 100644
--- a/vw-bap.h
+++ b/vw-bap.h
@@ -6,7 +6,7 @@
typedef unsigned char BAP_OpCode;
typedef unsigned char BAP_Node;
-typedef unsigned char BAP_Function;
+typedef unsigned char BAP_Port;
typedef unsigned short BAP_FrameLen;
@@ -32,11 +32,11 @@ struct BAP_Frame {
*/
BAP_Node node;
/* The "RPC" function, or "status register" ID.
*
- * BAP's equivalent of a "TCP port".
+ * BAP's equivalent of a "UDP port".
*/
- BAP_Function function;
+ BAP_Port port;
/* Payload length, up to 2^12-1 = 4095 bytes. */
BAP_FrameLen len;
@@ -32,11 +32,11 @@ struct BAP_Frame {
*/
BAP_Node node;
- /* The "RPC" function, or "status register" ID.
+ /* The "RPC" port, or "status register" ID.
*